@@ -55,22 +55,28 @@ def remote_call(remote_endpoint):
         return make_rsp('send to gourd server fail. e: %s' % e)
 
     socket_map[unique_id] = sock
+    f = sock.makefile('rw')
 
     def generate():
         yield make_rsp('unique_id: %s' % unique_id)
 
         while True:
-            f = sock.makefile('rw')
             current_app.logger.debug('waiting data...')
-            recv_data = f.readline()
+            try:
+                recv_data = f.readline()
+            except Exception, e:
+                yield make_rsp('readline raise exception: %s' % e)
+                break
+
             if not recv_data:
-                current_app.logger.debug('gourd server closed socket')
-                yield make_rsp('gourd server closed socket')
                 if unique_id in socket_map:
+                    yield make_rsp('server side closed socket')
                     socket_map.pop(unique_id).close()
+                else:
+                    yield make_rsp('client side closed socket')
                 break
             else:
-                current_app.logger.debug('recv_data: %s', recv_data)
+                current_app.logger.debug('recv_data: %s' % recv_data)
                 try:
                     jdata = json.loads(recv_data)
                     yield make_rsp(jdata)
@@ -88,7 +94,8 @@ def close_conn(unique_id):
     if not sock:
         return make_rsp('sock not in socket_map')
     else:
-        sock.close()
+        # 这个是真正破坏掉链接，close则不会
+        sock.shutdown(socket.SHUT_RDWR)
         return make_rsp('sock succ closed')
 
 
